==> geopsypack-src-3.4.0.tar.gz: geopsypack-src-3.4.0/SciFigs/src/PointProperties.h <==
/***************************************************************************
**
**  This file is part of SciFigs.
**
**  This library is free software; you can redistribute it and/or
**  modify it under the terms of the GNU Lesser General Public
**  License as published by the Free Software Foundation; either
**  version 2.1 of the License, or (at your option) any later version.
**
**  This file is distributed in the hope that it will be useful, but WITHOUT
**  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
**  FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public
**  License for more details.
**
**  You should have received a copy of the GNU Lesser General Public
**  License along with this library; if not, write to the Free Software
**  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
**
**  See http://www.geopsy.org for more information.
**
**  Created: 2005-07-04
**  Copyright: 2005-2019
**    Marc Wathelet
**    Marc Wathelet (LGIT, Grenoble, France)
**
***************************************************************************/

#ifndef POINTPROPERTIES_H
#define POINTPROPERTIES_H

#include <QGpGuiTools.h>
#include "ui_PointProperties.h"

namespace SciFigs {

class PointProperties : public Dialog, public Ui::PointProperties
{
  Q_OBJECT
public:
  PointProperties(QWidget * parent,
                     QVector<QString> * names,
                     QVector<QColor> * colors,
                     QVector<int> * indexList);
  ~PointProperties();
  void getResults(QVector<double> * x,
                  QVector<double> * y,
                  QVector<QString> * names,
                  QVector<QColor> * colors);
private slots:
  void on_colorBut_clicked();
  void on_deleteBut_clicked();
  void on_nameTable_itemClicked(QTableWidgetItem * item);
};

} // namespace SciFigs

#endif // POINTPROPERTIES_H

==> geopsypack-src-3.5.1.tar.gz: geopsypack-src-3.5.1/SciFigs/src/PointProperties.h <==
/***************************************************************************
**
**  This file is part of SciFigs.
**
**  This library is free software; you can redistribute it and/or
**  modify it under the terms of the GNU Lesser General Public
**  License as published by the Free Software Foundation; either
**  version 2.1 of the License, or (at your option) any later version.
**
**  This file is distributed in the hope that it will be useful, but WITHOUT
**  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
**  FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public
**  License for more details.
**
**  You should have received a copy of the GNU Lesser General Public
**  License along with this library; if not, write to the Free Software
**  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
**
**  See http://www.geopsy.org for more information.
**
**  Created: 2005-07-04
**  Copyright: 2005-2019
**    Marc Wathelet
**    Marc Wathelet (LGIT, Grenoble, France)
**
***************************************************************************/

#ifndef POINTPROPERTIES_H
#define POINTPROPERTIES_H

#include <QGpGuiTools.h>
#include "ui_PointProperties.h"

namespace SciFigs {

class PointProperties : public Dialog, public Ui::PointProperties
{
  Q_OBJECT
public:
  PointProperties(QWidget * parent,
                     VectorList<QString> * names,
                     VectorList<QColor> * colors,
                     VectorList<int> * indexList);
  ~PointProperties();
  void getResults(VectorList<double> * x,
                  VectorList<double> * y,
                  VectorList<QString> * names,
                  VectorList<QColor> * colors);
private slots:
  void on_colorBut_clicked();
  void on_deleteBut_clicked();
  void on_nameTable_itemClicked(QTableWidgetItem * item);
};

} // namespace SciFigs

#endif // POINTPROPERTIES_H
